@@ -181,50 +181,8 @@ class NBWorker(WSClient):
             else:
                 self.nb = copy.deepcopy(self.nb_original)
 
-            for i in range(index_execute_from, len(self.nb.cells) + 1):
-                log.debug(f"Execute cell index={i-1}")
+            self.nbrun.run_notebook(self.nb, start=index_execute_from - 1)
 
-                self.nbrun.run_cell(self.nb.cells[i - 1], counter=i)
-
-            """
-                print(self.nb.cells[i - 1])
-
-                for output in self.nb.cells[i - 1].get("outputs", []):
-                    if "data" in output:
-                        if "application/mercury+json" in output["data"]:
-                            w = output["data"]["application/mercury+json"]
-                            log.debug(w)
-                            w = json.loads(w)
-
-                            # prepare msg to send by ws
-                            msg = WidgetsManager.frontend_format(w)
-                            if msg:
-                                msg["purpose"] = Purpose.UpdateWidgets
-                                msg["widgetKey"] = w.get("code_uid")
-                                log.debug(f"Update widget {msg}")
-                                self.ws.send(json.dumps(msg))
-
-            # check if hide some widgets
-            nb_widgets_keys = []
-            for cell in self.nb.cells:
-                for output in cell.get("outputs", []):
-                    w = output.get("data", {}).get("application/mercury+json")
-                    if w is not None:
-                        w = json.loads(w)
-                        code_uid = w.get("code_uid")
-                        if code_uid is not None:
-                            nb_widgets_keys += [code_uid]
-
-            hide_widgets = []
-            for widget_key in widgets.keys():
-                if widget_key not in nb_widgets_keys:
-                    hide_widgets += [widget_key]
-
-            log.debug(f"Hide widgets {hide_widgets}")
-            if hide_widgets:
-                msg = {"purpose": Purpose.HideWidgets, "keys": hide_widgets}
-                self.ws.send(json.dumps(msg))
-            """
             self.send_widgets(self.nb, expected_widgets_keys=widgets.keys())
             self.prev_nb = copy.deepcopy(self.nb)
         else:
@@ -348,7 +306,7 @@ class NBWorker(WSClient):
             "description",
             "show_sidebar",
             "full_screen",
-            "allow_download"
+            "allow_download",
         ]:
             if params.get(property) is not None and nb_params.get(
                 property
